This directory is where thirdparty tools are stored (Yabber, etc). It is only used when sourcing new gamedata using `erdb.py source` command.

For a detailed description on which tool sources what, refer to the `gamedata/_Extracted/manifest.json` file.